# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetDeadLockDetailListResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetDeadLockDetailListResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request is successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request is successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetDeadLockDetailListResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetDeadLockDetailListResponseBodyData(DaraModel):
    def __init__(
        self,
        list: List[main_models.GetDeadLockDetailListResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The details of the data returned.
        self.list = list
        # The page number.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetDeadLockDetailListResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetDeadLockDetailListResponseBodyDataList(DaraModel):
    def __init__(
        self,
        batch_id: int = None,
        block_process_list: List[main_models.GetDeadLockDetailListResponseBodyDataListBlockProcessList] = None,
        client_app: str = None,
        database_name: str = None,
        host_name: str = None,
        last_tran_started: int = None,
        lock_mode: str = None,
        log_used: int = None,
        login_name: str = None,
        object_owned: str = None,
        object_requested: str = None,
        own_mode: str = None,
        spid: int = None,
        sql_text: str = None,
        status: str = None,
        victim: int = None,
        wait_mode: str = None,
        wait_resource: str = None,
        wait_resource_description: str = None,
    ):
        # The time when the data was collected. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.batch_id = batch_id
        # The blocking details of the instance. The details are information about the session that caused the lock.
        self.block_process_list = block_process_list
        # The name of the client.
        self.client_app = client_app
        # The name of the database.
        self.database_name = database_name
        # The hostname.
        self.host_name = host_name
        # The time when the transaction was started. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.last_tran_started = last_tran_started
        # The mode of the lock. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.lock_mode = lock_mode
        # The size of the logs generated in the session. Unit: bytes.
        self.log_used = log_used
        # The logon name of the user.
        self.login_name = login_name
        # The locked object.
        self.object_owned = object_owned
        # The object that the transaction requested to lock.
        self.object_requested = object_requested
        # The lock mode held by the session. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.own_mode = own_mode
        # The ID of the session in which the transaction is started.
        self.spid = spid
        # The SQL statement.
        self.sql_text = sql_text
        # The status of the transaction.
        self.status = status
        # Indicates whether the session is the victim of the deadlock. Valid values:
        # 
        # *   **0**: no.
        # *   **1**: yes.
        self.victim = victim
        # The lock mode requested by the session. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.wait_mode = wait_mode
        # The resources requested by the transaction.
        self.wait_resource = wait_resource
        # The details of the resources requested by the transaction.
        self.wait_resource_description = wait_resource_description

    def validate(self):
        if self.block_process_list:
            for v1 in self.block_process_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.batch_id is not None:
            result['BatchId'] = self.batch_id

        result['BlockProcessList'] = []
        if self.block_process_list is not None:
            for k1 in self.block_process_list:
                result['BlockProcessList'].append(k1.to_map() if k1 else None)

        if self.client_app is not None:
            result['ClientApp'] = self.client_app

        if self.database_name is not None:
            result['DatabaseName'] = self.database_name

        if self.host_name is not None:
            result['HostName'] = self.host_name

        if self.last_tran_started is not None:
            result['LastTranStarted'] = self.last_tran_started

        if self.lock_mode is not None:
            result['LockMode'] = self.lock_mode

        if self.log_used is not None:
            result['LogUsed'] = self.log_used

        if self.login_name is not None:
            result['LoginName'] = self.login_name

        if self.object_owned is not None:
            result['ObjectOwned'] = self.object_owned

        if self.object_requested is not None:
            result['ObjectRequested'] = self.object_requested

        if self.own_mode is not None:
            result['OwnMode'] = self.own_mode

        if self.spid is not None:
            result['Spid'] = self.spid

        if self.sql_text is not None:
            result['SqlText'] = self.sql_text

        if self.status is not None:
            result['Status'] = self.status

        if self.victim is not None:
            result['Victim'] = self.victim

        if self.wait_mode is not None:
            result['WaitMode'] = self.wait_mode

        if self.wait_resource is not None:
            result['WaitResource'] = self.wait_resource

        if self.wait_resource_description is not None:
            result['WaitResourceDescription'] = self.wait_resource_description

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BatchId') is not None:
            self.batch_id = m.get('BatchId')

        self.block_process_list = []
        if m.get('BlockProcessList') is not None:
            for k1 in m.get('BlockProcessList'):
                temp_model = main_models.GetDeadLockDetailListResponseBodyDataListBlockProcessList()
                self.block_process_list.append(temp_model.from_map(k1))

        if m.get('ClientApp') is not None:
            self.client_app = m.get('ClientApp')

        if m.get('DatabaseName') is not None:
            self.database_name = m.get('DatabaseName')

        if m.get('HostName') is not None:
            self.host_name = m.get('HostName')

        if m.get('LastTranStarted') is not None:
            self.last_tran_started = m.get('LastTranStarted')

        if m.get('LockMode') is not None:
            self.lock_mode = m.get('LockMode')

        if m.get('LogUsed') is not None:
            self.log_used = m.get('LogUsed')

        if m.get('LoginName') is not None:
            self.login_name = m.get('LoginName')

        if m.get('ObjectOwned') is not None:
            self.object_owned = m.get('ObjectOwned')

        if m.get('ObjectRequested') is not None:
            self.object_requested = m.get('ObjectRequested')

        if m.get('OwnMode') is not None:
            self.own_mode = m.get('OwnMode')

        if m.get('Spid') is not None:
            self.spid = m.get('Spid')

        if m.get('SqlText') is not None:
            self.sql_text = m.get('SqlText')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('Victim') is not None:
            self.victim = m.get('Victim')

        if m.get('WaitMode') is not None:
            self.wait_mode = m.get('WaitMode')

        if m.get('WaitResource') is not None:
            self.wait_resource = m.get('WaitResource')

        if m.get('WaitResourceDescription') is not None:
            self.wait_resource_description = m.get('WaitResourceDescription')

        return self

class GetDeadLockDetailListResponseBodyDataListBlockProcessList(DaraModel):
    def __init__(
        self,
        client_app: str = None,
        database_name: str = None,
        host_name: str = None,
        last_tran_started: int = None,
        lock_mode: str = None,
        log_used: int = None,
        login_name: str = None,
        object_owned: str = None,
        object_requested: str = None,
        own_mode: str = None,
        spid: int = None,
        sql_text: str = None,
        status: str = None,
        victim: int = None,
        wait_mode: str = None,
        wait_resource: str = None,
        wait_resource_description: str = None,
    ):
        # The name of the client that initiates the transaction in the session.
        self.client_app = client_app
        # The name of the database.
        self.database_name = database_name
        # The hostname.
        self.host_name = host_name
        # The time when the transaction was started. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.last_tran_started = last_tran_started
        # The mode of the lock. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.lock_mode = lock_mode
        # The size of the logs generated in the session. Unit: bytes.
        self.log_used = log_used
        # The logon name of the user.
        self.login_name = login_name
        # The locked object.
        self.object_owned = object_owned
        # The object that the transaction requested to lock.
        self.object_requested = object_requested
        # The lock mode held by the session. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.own_mode = own_mode
        # The ID of the session in which the transaction is started.
        self.spid = spid
        # The SQL statement.
        self.sql_text = sql_text
        # The status of the transaction.
        self.status = status
        # Indicates whether the session is the victim of the deadlock. Valid values:
        # 
        # *   **0**: no.
        # *   **1**: yes.
        self.victim = victim
        # The lock mode requested by the session. For more information, see [Lock modes](https://help.aliyun.com/document_detail/2362804.html).
        self.wait_mode = wait_mode
        # The resources requested by the transaction.
        self.wait_resource = wait_resource
        # The details of the resources requested by the transaction.
        self.wait_resource_description = wait_resource_description

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_app is not None:
            result['ClientApp'] = self.client_app

        if self.database_name is not None:
            result['DatabaseName'] = self.database_name

        if self.host_name is not None:
            result['HostName'] = self.host_name

        if self.last_tran_started is not None:
            result['LastTranStarted'] = self.last_tran_started

        if self.lock_mode is not None:
            result['LockMode'] = self.lock_mode

        if self.log_used is not None:
            result['LogUsed'] = self.log_used

        if self.login_name is not None:
            result['LoginName'] = self.login_name

        if self.object_owned is not None:
            result['ObjectOwned'] = self.object_owned

        if self.object_requested is not None:
            result['ObjectRequested'] = self.object_requested

        if self.own_mode is not None:
            result['OwnMode'] = self.own_mode

        if self.spid is not None:
            result['Spid'] = self.spid

        if self.sql_text is not None:
            result['SqlText'] = self.sql_text

        if self.status is not None:
            result['Status'] = self.status

        if self.victim is not None:
            result['Victim'] = self.victim

        if self.wait_mode is not None:
            result['WaitMode'] = self.wait_mode

        if self.wait_resource is not None:
            result['WaitResource'] = self.wait_resource

        if self.wait_resource_description is not None:
            result['WaitResourceDescription'] = self.wait_resource_description

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClientApp') is not None:
            self.client_app = m.get('ClientApp')

        if m.get('DatabaseName') is not None:
            self.database_name = m.get('DatabaseName')

        if m.get('HostName') is not None:
            self.host_name = m.get('HostName')

        if m.get('LastTranStarted') is not None:
            self.last_tran_started = m.get('LastTranStarted')

        if m.get('LockMode') is not None:
            self.lock_mode = m.get('LockMode')

        if m.get('LogUsed') is not None:
            self.log_used = m.get('LogUsed')

        if m.get('LoginName') is not None:
            self.login_name = m.get('LoginName')

        if m.get('ObjectOwned') is not None:
            self.object_owned = m.get('ObjectOwned')

        if m.get('ObjectRequested') is not None:
            self.object_requested = m.get('ObjectRequested')

        if m.get('OwnMode') is not None:
            self.own_mode = m.get('OwnMode')

        if m.get('Spid') is not None:
            self.spid = m.get('Spid')

        if m.get('SqlText') is not None:
            self.sql_text = m.get('SqlText')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('Victim') is not None:
            self.victim = m.get('Victim')

        if m.get('WaitMode') is not None:
            self.wait_mode = m.get('WaitMode')

        if m.get('WaitResource') is not None:
            self.wait_resource = m.get('WaitResource')

        if m.get('WaitResourceDescription') is not None:
            self.wait_resource_description = m.get('WaitResourceDescription')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSqlLogTasksResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSqlLogTasksResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The response code.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSqlLogTasksResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSqlLogTasksResponseBodyData(DaraModel):
    def __init__(
        self,
        list: List[main_models.DescribeSqlLogTasksResponseBodyDataList] = None,
        page_no: int = None,
        page_size: int = None,
        total: int = None,
    ):
        # The details of the data returned.
        self.list = list
        # The page number.
        self.page_no = page_no
        # The number of entries per page.
        self.page_size = page_size
        # The number of tasks.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.DescribeSqlLogTasksResponseBodyDataList()
                self.list.append(temp_model.from_map(k1))

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class DescribeSqlLogTasksResponseBodyDataList(DaraModel):
    def __init__(
        self,
        analysis_task_finish_time: int = None,
        analysis_task_status: str = None,
        create_time: int = None,
        end: int = None,
        expire: bool = None,
        filters: List[main_models.DescribeSqlLogTasksResponseBodyDataListFilters] = None,
        inner_result: str = None,
        instance_id: str = None,
        log_count: int = None,
        name: str = None,
        progress: int = None,
        result: str = None,
        scan_file_size: int = None,
        start: int = None,
        status: str = None,
        task_id: str = None,
        task_type: str = None,
    ):
        # The time when the analysis task was complete. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.analysis_task_finish_time = analysis_task_finish_time
        # The state of the analysis task.
        # 
        # >  This parameter is a system parameter. You do not need to pay attention to the parameter.
        self.analysis_task_status = analysis_task_status
        # The time when the task was created. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.create_time = create_time
        # The time when the task ended. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.end = end
        # Indicates whether the task expired. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.expire = expire
        # The filter parameters.
        self.filters = filters
        self.inner_result = inner_result
        # The ID of the database instance.
        self.instance_id = instance_id
        # The number of log records.
        self.log_count = log_count
        # The task name.
        self.name = name
        # The task progress.
        self.progress = progress
        # The URL that is returned if the value of TaskType is **Export**.
        self.result = result
        # The number of files that are scanned.
        self.scan_file_size = scan_file_size
        # The time when the task started. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start = start
        # The task state. Valid values:
        # 
        # *   **INIT**: The task is to be scheduled.
        # *   **RUNNING**: The task is running.
        # *   **FAILED**: The task failed.
        # *   **CANCELED**: The task is canceled.
        # *   **COMPLETED**: The task is complete.
        # 
        # >  If a task is in the **COMPLETED** state, you can view the results of the task.
        self.status = status
        # The task ID.
        self.task_id = task_id
        # The task type. Valid values:
        # 
        # *   **Export**
        # *   **Query**
        self.task_type = task_type

    def validate(self):
        if self.filters:
            for v1 in self.filters:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.analysis_task_finish_time is not None:
            result['AnalysisTaskFinishTime'] = self.analysis_task_finish_time

        if self.analysis_task_status is not None:
            result['AnalysisTaskStatus'] = self.analysis_task_status

        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.end is not None:
            result['End'] = self.end

        if self.expire is not None:
            result['Expire'] = self.expire

        result['Filters'] = []
        if self.filters is not None:
            for k1 in self.filters:
                result['Filters'].append(k1.to_map() if k1 else None)

        if self.inner_result is not None:
            result['InnerResult'] = self.inner_result

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.log_count is not None:
            result['LogCount'] = self.log_count

        if self.name is not None:
            result['Name'] = self.name

        if self.progress is not None:
            result['Progress'] = self.progress

        if self.result is not None:
            result['Result'] = self.result

        if self.scan_file_size is not None:
            result['ScanFileSize'] = self.scan_file_size

        if self.start is not None:
            result['Start'] = self.start

        if self.status is not None:
            result['Status'] = self.status

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_type is not None:
            result['TaskType'] = self.task_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AnalysisTaskFinishTime') is not None:
            self.analysis_task_finish_time = m.get('AnalysisTaskFinishTime')

        if m.get('AnalysisTaskStatus') is not None:
            self.analysis_task_status = m.get('AnalysisTaskStatus')

        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('End') is not None:
            self.end = m.get('End')

        if m.get('Expire') is not None:
            self.expire = m.get('Expire')

        self.filters = []
        if m.get('Filters') is not None:
            for k1 in m.get('Filters'):
                temp_model = main_models.DescribeSqlLogTasksResponseBodyDataListFilters()
                self.filters.append(temp_model.from_map(k1))

        if m.get('InnerResult') is not None:
            self.inner_result = m.get('InnerResult')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('LogCount') is not None:
            self.log_count = m.get('LogCount')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Progress') is not None:
            self.progress = m.get('Progress')

        if m.get('Result') is not None:
            self.result = m.get('Result')

        if m.get('ScanFileSize') is not None:
            self.scan_file_size = m.get('ScanFileSize')

        if m.get('Start') is not None:
            self.start = m.get('Start')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskType') is not None:
            self.task_type = m.get('TaskType')

        return self

class DescribeSqlLogTasksResponseBodyDataListFilters(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The name of the filter parameter.
        # 
        # >  For more information about the filter parameters, see the **Valid values of Key** section of this topic.
        self.key = key
        # The value of the filter parameter.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._data_result_value import DataResultValue
from ._data_session_stat_client_stats_value import DataSessionStatClientStatsValue
from ._data_session_stat_db_stats_value import DataSessionStatDbStatsValue
from ._data_value import DataValue
from ._add_hdminstance_request import AddHDMInstanceRequest
from ._add_hdminstance_response_body import AddHDMInstanceResponseBody
from ._add_hdminstance_response import AddHDMInstanceResponse
from ._create_cache_analysis_job_request import CreateCacheAnalysisJobRequest
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBody
from ._create_cache_analysis_job_response import CreateCacheAnalysisJobResponse
from ._create_cloud_bench_tasks_request import CreateCloudBenchTasksRequest
from ._create_cloud_bench_tasks_response_body import CreateCloudBenchTasksResponseBody
from ._create_cloud_bench_tasks_response import CreateCloudBenchTasksResponse
from ._create_diagnostic_report_request import CreateDiagnosticReportRequest
from ._create_diagnostic_report_response_body import CreateDiagnosticReportResponseBody
from ._create_diagnostic_report_response import CreateDiagnosticReportResponse
from ._create_kill_instance_session_task_request import CreateKillInstanceSessionTaskRequest
from ._create_kill_instance_session_task_response_body import CreateKillInstanceSessionTaskResponseBody
from ._create_kill_instance_session_task_response import CreateKillInstanceSessionTaskResponse
from ._create_kill_instance_session_task_with_maintain_user_request import CreateKillInstanceSessionTaskWithMaintainUserRequest
from ._create_kill_instance_session_task_with_maintain_user_response_body import CreateKillInstanceSessionTaskWithMaintainUserResponseBody
from ._create_kill_instance_session_task_with_maintain_user_response import CreateKillInstanceSessionTaskWithMaintainUserResponse
from ._create_latest_dead_lock_analysis_request import CreateLatestDeadLockAnalysisRequest
from ._create_latest_dead_lock_analysis_response_body import CreateLatestDeadLockAnalysisResponseBody
from ._create_latest_dead_lock_analysis_response import CreateLatestDeadLockAnalysisResponse
from ._create_query_optimize_tag_request import CreateQueryOptimizeTagRequest
from ._create_query_optimize_tag_response_body import CreateQueryOptimizeTagResponseBody
from ._create_query_optimize_tag_response import CreateQueryOptimizeTagResponse
from ._create_request_diagnosis_request import CreateRequestDiagnosisRequest
from ._create_request_diagnosis_response_body import CreateRequestDiagnosisResponseBody
from ._create_request_diagnosis_response import CreateRequestDiagnosisResponse
from ._create_security_ipgroup_request import CreateSecurityIPGroupRequest
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBody
from ._create_security_ipgroup_response import CreateSecurityIPGroupResponse
from ._create_sql_log_task_request import CreateSqlLogTaskRequest
from ._create_sql_log_task_response_body import CreateSqlLogTaskResponseBody
from ._create_sql_log_task_response import CreateSqlLogTaskResponse
from ._create_storage_analysis_task_request import CreateStorageAnalysisTaskRequest
from ._create_storage_analysis_task_response_body import CreateStorageAnalysisTaskResponseBody
from ._create_storage_analysis_task_response import CreateStorageAnalysisTaskResponse
from ._delete_cloud_bench_task_request import DeleteCloudBenchTaskRequest
from ._delete_cloud_bench_task_response_body import DeleteCloudBenchTaskResponseBody
from ._delete_cloud_bench_task_response import DeleteCloudBenchTaskResponse
from ._delete_security_ipgroup_request import DeleteSecurityIPGroupRequest
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBody
from ._delete_security_ipgroup_response import DeleteSecurityIPGroupResponse
from ._delete_stop_gateway_request import DeleteStopGatewayRequest
from ._delete_stop_gateway_response_body import DeleteStopGatewayResponseBody
from ._delete_stop_gateway_response import DeleteStopGatewayResponse
from ._describe_auto_scaling_config_request import DescribeAutoScalingConfigRequest
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBody
from ._describe_auto_scaling_config_response import DescribeAutoScalingConfigResponse
from ._describe_auto_scaling_history_request import DescribeAutoScalingHistoryRequest
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBody
from ._describe_auto_scaling_history_response import DescribeAutoScalingHistoryResponse
from ._describe_cache_analysis_job_request import DescribeCacheAnalysisJobRequest
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBody
from ._describe_cache_analysis_job_response import DescribeCacheAnalysisJobResponse
from ._describe_cache_analysis_jobs_request import DescribeCacheAnalysisJobsRequest
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBody
from ._describe_cache_analysis_jobs_response import DescribeCacheAnalysisJobsResponse
from ._describe_cloud_bench_tasks_request import DescribeCloudBenchTasksRequest
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBody
from ._describe_cloud_bench_tasks_response import DescribeCloudBenchTasksResponse
from ._describe_cloudbench_task_request import DescribeCloudbenchTaskRequest
from ._describe_cloudbench_task_response_body import DescribeCloudbenchTaskResponseBody
from ._describe_cloudbench_task_response import DescribeCloudbenchTaskResponse
from ._describe_cloudbench_task_config_request import DescribeCloudbenchTaskConfigRequest
from ._describe_cloudbench_task_config_response_body import DescribeCloudbenchTaskConfigResponseBody
from ._describe_cloudbench_task_config_response import DescribeCloudbenchTaskConfigResponse
from ._describe_diagnostic_report_list_request import DescribeDiagnosticReportListRequest
from ._describe_diagnostic_report_list_response_body import DescribeDiagnosticReportListResponseBody
from ._describe_diagnostic_report_list_response import DescribeDiagnosticReportListResponse
from ._describe_error_log_records_request import DescribeErrorLogRecordsRequest
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBody
from ._describe_error_log_records_response import DescribeErrorLogRecordsResponse
from ._describe_hot_big_keys_request import DescribeHotBigKeysRequest
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBody
from ._describe_hot_big_keys_response import DescribeHotBigKeysResponse
from ._describe_hot_keys_request import DescribeHotKeysRequest
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBody
from ._describe_hot_keys_response import DescribeHotKeysResponse
from ._describe_instance_das_pro_request import DescribeInstanceDasProRequest
from ._describe_instance_das_pro_response_body import DescribeInstanceDasProResponseBody
from ._describe_instance_das_pro_response import DescribeInstanceDasProResponse
from ._describe_query_explain_request import DescribeQueryExplainRequest
from ._describe_query_explain_response_body import DescribeQueryExplainResponseBody
from ._describe_query_explain_response import DescribeQueryExplainResponse
from ._describe_security_ipgroup_request import DescribeSecurityIPGroupRequest
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBody
from ._describe_security_ipgroup_response import DescribeSecurityIPGroupResponse
from ._describe_security_ipgroup_relation_request import DescribeSecurityIPGroupRelationRequest
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBody
from ._describe_security_ipgroup_relation_response import DescribeSecurityIPGroupRelationResponse
from ._describe_slow_log_histogram_async_request import DescribeSlowLogHistogramAsyncRequest
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBody
from ._describe_slow_log_histogram_async_response import DescribeSlowLogHistogramAsyncResponse
from ._describe_slow_log_records_request import DescribeSlowLogRecordsRequest
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBody
from ._describe_slow_log_records_response import DescribeSlowLogRecordsResponse
from ._describe_slow_log_statistic_request import DescribeSlowLogStatisticRequest
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBody
from ._describe_slow_log_statistic_response import DescribeSlowLogStatisticResponse
from ._describe_sql_log_config_request import DescribeSqlLogConfigRequest
from ._describe_sql_log_config_response_body import DescribeSqlLogConfigResponseBody
from ._describe_sql_log_config_response import DescribeSqlLogConfigResponse
from ._describe_sql_log_records_request import DescribeSqlLogRecordsRequest
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBody
from ._describe_sql_log_records_response import DescribeSqlLogRecordsResponse
from ._describe_sql_log_statistic_request import DescribeSqlLogStatisticRequest
from ._describe_sql_log_statistic_response_body import DescribeSqlLogStatisticResponseBody
from ._describe_sql_log_statistic_response import DescribeSqlLogStatisticResponse
from ._describe_sql_log_task_request import DescribeSqlLogTaskRequest
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBody
from ._describe_sql_log_task_response import DescribeSqlLogTaskResponse
from ._describe_sql_log_tasks_request import DescribeSqlLogTasksRequest
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBody
from ._describe_sql_log_tasks_response import DescribeSqlLogTasksResponse
from ._describe_top_big_keys_request import DescribeTopBigKeysRequest
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBody
from ._describe_top_big_keys_response import DescribeTopBigKeysResponse
from ._describe_top_hot_keys_request import DescribeTopHotKeysRequest
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBody
from ._describe_top_hot_keys_response import DescribeTopHotKeysResponse
from ._disable_all_sql_concurrency_control_rules_request import DisableAllSqlConcurrencyControlRulesRequest
from ._disable_all_sql_concurrency_control_rules_response_body import DisableAllSqlConcurrencyControlRulesResponseBody
from ._disable_all_sql_concurrency_control_rules_response import DisableAllSqlConcurrencyControlRulesResponse
from ._disable_auto_resource_optimize_rules_request import DisableAutoResourceOptimizeRulesRequest
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBody
from ._disable_auto_resource_optimize_rules_response import DisableAutoResourceOptimizeRulesResponse
from ._disable_auto_throttle_rules_request import DisableAutoThrottleRulesRequest
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBody
from ._disable_auto_throttle_rules_response import DisableAutoThrottleRulesResponse
from ._disable_das_pro_request import DisableDasProRequest
from ._disable_das_pro_response_body import DisableDasProResponseBody
from ._disable_das_pro_response import DisableDasProResponse
from ._disable_instance_das_config_request import DisableInstanceDasConfigRequest
from ._disable_instance_das_config_response_body import DisableInstanceDasConfigResponseBody
from ._disable_instance_das_config_response import DisableInstanceDasConfigResponse
from ._disable_sql_concurrency_control_request import DisableSqlConcurrencyControlRequest
from ._disable_sql_concurrency_control_response_body import DisableSqlConcurrencyControlResponseBody
from ._disable_sql_concurrency_control_response import DisableSqlConcurrencyControlResponse
from ._enable_das_pro_request import EnableDasProRequest
from ._enable_das_pro_response_body import EnableDasProResponseBody
from ._enable_das_pro_response import EnableDasProResponse
from ._enable_sql_concurrency_control_request import EnableSqlConcurrencyControlRequest
from ._enable_sql_concurrency_control_response_body import EnableSqlConcurrencyControlResponseBody
from ._enable_sql_concurrency_control_response import EnableSqlConcurrencyControlResponse
from ._get_async_error_request_list_by_code_request import GetAsyncErrorRequestListByCodeRequest
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBody
from ._get_async_error_request_list_by_code_response import GetAsyncErrorRequestListByCodeResponse
from ._get_async_error_request_stat_by_code_request import GetAsyncErrorRequestStatByCodeRequest
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBody
from ._get_async_error_request_stat_by_code_response import GetAsyncErrorRequestStatByCodeResponse
from ._get_async_error_request_stat_result_request import GetAsyncErrorRequestStatResultRequest
from ._get_async_error_request_stat_result_response_body import GetAsyncErrorRequestStatResultResponseBody
from ._get_async_error_request_stat_result_response import GetAsyncErrorRequestStatResultResponse
from ._get_auto_increment_usage_statistic_request import GetAutoIncrementUsageStatisticRequest
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBody
from ._get_auto_increment_usage_statistic_response import GetAutoIncrementUsageStatisticResponse
from ._get_auto_resource_optimize_rules_request import GetAutoResourceOptimizeRulesRequest
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBody
from ._get_auto_resource_optimize_rules_response import GetAutoResourceOptimizeRulesResponse
from ._get_auto_throttle_rules_request import GetAutoThrottleRulesRequest
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBody
from ._get_auto_throttle_rules_response import GetAutoThrottleRulesResponse
from ._get_autonomous_notify_event_content_request import GetAutonomousNotifyEventContentRequest
from ._get_autonomous_notify_event_content_response_body import GetAutonomousNotifyEventContentResponseBody
from ._get_autonomous_notify_event_content_response import GetAutonomousNotifyEventContentResponse
from ._get_autonomous_notify_events_in_range_request import GetAutonomousNotifyEventsInRangeRequest
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBody
from ._get_autonomous_notify_events_in_range_response import GetAutonomousNotifyEventsInRangeResponse
from ._get_blocking_detail_list_request import GetBlockingDetailListRequest
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBody
from ._get_blocking_detail_list_response import GetBlockingDetailListResponse
from ._get_dbinstance_connectivity_diagnosis_request import GetDBInstanceConnectivityDiagnosisRequest
from ._get_dbinstance_connectivity_diagnosis_response_body import GetDBInstanceConnectivityDiagnosisResponseBody
from ._get_dbinstance_connectivity_diagnosis_response import GetDBInstanceConnectivityDiagnosisResponse
from ._get_das_agent_sserequest import GetDasAgentSSERequest
from ._get_das_agent_sseresponse_body import GetDasAgentSSEResponseBody
from ._get_das_agent_sseresponse import GetDasAgentSSEResponse
from ._get_das_pro_service_usage_request import GetDasProServiceUsageRequest
from ._get_das_pro_service_usage_response_body import GetDasProServiceUsageResponseBody
from ._get_das_pro_service_usage_response import GetDasProServiceUsageResponse
from ._get_das_sqllog_hot_data_request import GetDasSQLLogHotDataRequest
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBody
from ._get_das_sqllog_hot_data_response import GetDasSQLLogHotDataResponse
from ._get_dead_lock_detail_request import GetDeadLockDetailRequest
from ._get_dead_lock_detail_response_body import GetDeadLockDetailResponseBody
from ._get_dead_lock_detail_response import GetDeadLockDetailResponse
from ._get_dead_lock_detail_list_request import GetDeadLockDetailListRequest
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBody
from ._get_dead_lock_detail_list_response import GetDeadLockDetailListResponse
from ._get_dead_lock_history_request import GetDeadLockHistoryRequest
from ._get_dead_lock_history_response_body import GetDeadLockHistoryResponseBody
from ._get_dead_lock_history_response import GetDeadLockHistoryResponse
from ._get_deadlock_histogram_request import GetDeadlockHistogramRequest
from ._get_deadlock_histogram_response_body import GetDeadlockHistogramResponseBody
from ._get_deadlock_histogram_response import GetDeadlockHistogramResponse
from ._get_endpoint_switch_task_request import GetEndpointSwitchTaskRequest
from ._get_endpoint_switch_task_response_body import GetEndpointSwitchTaskResponseBody
from ._get_endpoint_switch_task_response import GetEndpointSwitchTaskResponse
from ._get_error_request_sample_request import GetErrorRequestSampleRequest
from ._get_error_request_sample_response_body import GetErrorRequestSampleResponseBody
from ._get_error_request_sample_response import GetErrorRequestSampleResponse
from ._get_event_subscription_request import GetEventSubscriptionRequest
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBody
from ._get_event_subscription_response import GetEventSubscriptionResponse
from ._get_full_request_origin_stat_by_instance_id_request import GetFullRequestOriginStatByInstanceIdRequest
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBody
from ._get_full_request_origin_stat_by_instance_id_response import GetFullRequestOriginStatByInstanceIdResponse
from ._get_full_request_sample_by_instance_id_request import GetFullRequestSampleByInstanceIdRequest
from ._get_full_request_sample_by_instance_id_response_body import GetFullRequestSampleByInstanceIdResponseBody
from ._get_full_request_sample_by_instance_id_response import GetFullRequestSampleByInstanceIdResponse
from ._get_full_request_stat_result_by_instance_id_request import GetFullRequestStatResultByInstanceIdRequest
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBody
from ._get_full_request_stat_result_by_instance_id_response import GetFullRequestStatResultByInstanceIdResponse
from ._get_hdmaliyun_resource_sync_result_request import GetHDMAliyunResourceSyncResultRequest
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBody
from ._get_hdmaliyun_resource_sync_result_response import GetHDMAliyunResourceSyncResultResponse
from ._get_hdmlast_aliyun_resource_sync_result_request import GetHDMLastAliyunResourceSyncResultRequest
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBody
from ._get_hdmlast_aliyun_resource_sync_result_response import GetHDMLastAliyunResourceSyncResultResponse
from ._get_instance_group_inspect_report_detail_request import GetInstanceGroupInspectReportDetailRequest
from ._get_instance_group_inspect_report_detail_response_body import GetInstanceGroupInspectReportDetailResponseBody
from ._get_instance_group_inspect_report_detail_response import GetInstanceGroupInspectReportDetailResponse
from ._get_instance_group_inspect_report_list_request import GetInstanceGroupInspectReportListRequest
from ._get_instance_group_inspect_report_list_response_body import GetInstanceGroupInspectReportListResponseBody
from ._get_instance_group_inspect_report_list_response import GetInstanceGroupInspectReportListResponse
from ._get_instance_inspections_request import GetInstanceInspectionsRequest
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBody
from ._get_instance_inspections_response import GetInstanceInspectionsResponse
from ._get_instance_missing_index_list_request import GetInstanceMissingIndexListRequest
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBody
from ._get_instance_missing_index_list_response import GetInstanceMissingIndexListResponse
from ._get_instance_sql_optimize_statistic_request import GetInstanceSqlOptimizeStatisticRequest
from ._get_instance_sql_optimize_statistic_response_body import GetInstanceSqlOptimizeStatisticResponseBody
from ._get_instance_sql_optimize_statistic_response import GetInstanceSqlOptimizeStatisticResponse
from ._get_kill_instance_session_task_result_request import GetKillInstanceSessionTaskResultRequest
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBody
from ._get_kill_instance_session_task_result_response import GetKillInstanceSessionTaskResultResponse
from ._get_mongo_dbcurrent_op_request import GetMongoDBCurrentOpRequest
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBody
from ._get_mongo_dbcurrent_op_response import GetMongoDBCurrentOpResponse
from ._get_my_sqlall_session_async_request import GetMySQLAllSessionAsyncRequest
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBody
from ._get_my_sqlall_session_async_response import GetMySQLAllSessionAsyncResponse
from ._get_partitions_heatmap_request import GetPartitionsHeatmapRequest
from ._get_partitions_heatmap_response_body import GetPartitionsHeatmapResponseBody
from ._get_partitions_heatmap_response import GetPartitionsHeatmapResponse
from ._get_pfs_metric_trends_request import GetPfsMetricTrendsRequest
from ._get_pfs_metric_trends_response_body import GetPfsMetricTrendsResponseBody
from ._get_pfs_metric_trends_response import GetPfsMetricTrendsResponse
from ._get_pfs_sql_sample_request import GetPfsSqlSampleRequest
from ._get_pfs_sql_sample_response_body import GetPfsSqlSampleResponseBody
from ._get_pfs_sql_sample_response import GetPfsSqlSampleResponse
from ._get_pfs_sql_summaries_request import GetPfsSqlSummariesRequest
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBody
from ._get_pfs_sql_summaries_response import GetPfsSqlSummariesResponse
from ._get_query_optimize_data_stats_request import GetQueryOptimizeDataStatsRequest
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBody
from ._get_query_optimize_data_stats_response import GetQueryOptimizeDataStatsResponse
from ._get_query_optimize_data_top_request import GetQueryOptimizeDataTopRequest
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBody
from ._get_query_optimize_data_top_response import GetQueryOptimizeDataTopResponse
from ._get_query_optimize_data_trend_request import GetQueryOptimizeDataTrendRequest
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBody
from ._get_query_optimize_data_trend_response import GetQueryOptimizeDataTrendResponse
from ._get_query_optimize_exec_error_sample_request import GetQueryOptimizeExecErrorSampleRequest
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBody
from ._get_query_optimize_exec_error_sample_response import GetQueryOptimizeExecErrorSampleResponse
from ._get_query_optimize_exec_error_stats_request import GetQueryOptimizeExecErrorStatsRequest
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBody
from ._get_query_optimize_exec_error_stats_response import GetQueryOptimizeExecErrorStatsResponse
from ._get_query_optimize_rule_list_request import GetQueryOptimizeRuleListRequest
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBody
from ._get_query_optimize_rule_list_response import GetQueryOptimizeRuleListResponse
from ._get_query_optimize_share_url_request import GetQueryOptimizeShareUrlRequest
from ._get_query_optimize_share_url_response_body import GetQueryOptimizeShareUrlResponseBody
from ._get_query_optimize_share_url_response import GetQueryOptimizeShareUrlResponse
from ._get_query_optimize_solution_request import GetQueryOptimizeSolutionRequest
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBody
from ._get_query_optimize_solution_response import GetQueryOptimizeSolutionResponse
from ._get_query_optimize_tag_request import GetQueryOptimizeTagRequest
from ._get_query_optimize_tag_response_body import GetQueryOptimizeTagResponseBody
from ._get_query_optimize_tag_response import GetQueryOptimizeTagResponse
from ._get_redis_all_session_request import GetRedisAllSessionRequest
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBody
from ._get_redis_all_session_response import GetRedisAllSessionResponse
from ._get_request_diagnosis_page_request import GetRequestDiagnosisPageRequest
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBody
from ._get_request_diagnosis_page_response import GetRequestDiagnosisPageResponse
from ._get_request_diagnosis_result_request import GetRequestDiagnosisResultRequest
from ._get_request_diagnosis_result_response_body import GetRequestDiagnosisResultResponseBody
from ._get_request_diagnosis_result_response import GetRequestDiagnosisResultResponse
from ._get_running_sql_concurrency_control_rules_request import GetRunningSqlConcurrencyControlRulesRequest
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBody
from ._get_running_sql_concurrency_control_rules_response import GetRunningSqlConcurrencyControlRulesResponse
from ._get_sql_concurrency_control_keywords_from_sql_text_request import GetSqlConcurrencyControlKeywordsFromSqlTextRequest
from ._get_sql_concurrency_control_keywords_from_sql_text_response_body import GetSqlConcurrencyControlKeywordsFromSqlTextResponseBody
from ._get_sql_concurrency_control_keywords_from_sql_text_response import GetSqlConcurrencyControlKeywordsFromSqlTextResponse
from ._get_sql_concurrency_control_rules_history_request import GetSqlConcurrencyControlRulesHistoryRequest
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBody
from ._get_sql_concurrency_control_rules_history_response import GetSqlConcurrencyControlRulesHistoryResponse
from ._get_sql_optimize_advice_request import GetSqlOptimizeAdviceRequest
from ._get_sql_optimize_advice_response_body import GetSqlOptimizeAdviceResponseBody
from ._get_sql_optimize_advice_response import GetSqlOptimizeAdviceResponse
from ._get_storage_analysis_result_request import GetStorageAnalysisResultRequest
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBody
from ._get_storage_analysis_result_response import GetStorageAnalysisResultResponse
from ._get_yao_chi_agent_request import GetYaoChiAgentRequest
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBody
from ._get_yao_chi_agent_response import GetYaoChiAgentResponse
from ._kill_instance_all_session_request import KillInstanceAllSessionRequest
from ._kill_instance_all_session_response_body import KillInstanceAllSessionResponseBody
from ._kill_instance_all_session_response import KillInstanceAllSessionResponse
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequest
from ._modify_auto_scaling_config_response_body import ModifyAutoScalingConfigResponseBody
from ._modify_auto_scaling_config_response import ModifyAutoScalingConfigResponse
from ._modify_security_ipgroup_request import ModifySecurityIPGroupRequest
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBody
from ._modify_security_ipgroup_response import ModifySecurityIPGroupResponse
from ._modify_security_ipgroup_relation_request import ModifySecurityIPGroupRelationRequest
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBody
from ._modify_security_ipgroup_relation_response import ModifySecurityIPGroupRelationResponse
from ._modify_sql_log_config_request import ModifySqlLogConfigRequest
from ._modify_sql_log_config_response_body import ModifySqlLogConfigResponseBody
from ._modify_sql_log_config_response import ModifySqlLogConfigResponse
from ._run_cloud_bench_task_request import RunCloudBenchTaskRequest
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBody
from ._run_cloud_bench_task_response import RunCloudBenchTaskResponse
from ._set_event_subscription_request import SetEventSubscriptionRequest
from ._set_event_subscription_response_body import SetEventSubscriptionResponseBody
from ._set_event_subscription_response import SetEventSubscriptionResponse
from ._update_auto_resource_optimize_rules_async_request import UpdateAutoResourceOptimizeRulesAsyncRequest
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBody
from ._update_auto_resource_optimize_rules_async_response import UpdateAutoResourceOptimizeRulesAsyncResponse
from ._update_auto_sql_optimize_status_request import UpdateAutoSqlOptimizeStatusRequest
from ._update_auto_sql_optimize_status_response_body import UpdateAutoSqlOptimizeStatusResponseBody
from ._update_auto_sql_optimize_status_response import UpdateAutoSqlOptimizeStatusResponse
from ._update_auto_throttle_rules_async_request import UpdateAutoThrottleRulesAsyncRequest
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBody
from ._update_auto_throttle_rules_async_response import UpdateAutoThrottleRulesAsyncResponse
from ._add_hdminstance_response_body import AddHDMInstanceResponseBodyData
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyDataBigKeys
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyData
from ._create_cloud_bench_tasks_response_body import CreateCloudBenchTasksResponseBodyData
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBodyData
from ._create_sql_log_task_request import CreateSqlLogTaskRequestFilters
from ._create_sql_log_task_response_body import CreateSqlLogTaskResponseBodyData
from ._create_storage_analysis_task_response_body import CreateStorageAnalysisTaskResponseBodyData
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBodyData
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataBandwidth
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataResource
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataShard
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataSpec
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataStorage
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyData
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBodyDataSpecHistory
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBodyData
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeys
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyData
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeysKeyInfo
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeys
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJob
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataList
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyData
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyDataList
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyData
from ._describe_cloudbench_task_response_body import DescribeCloudbenchTaskResponseBodyData
from ._describe_cloudbench_task_config_response_body import DescribeCloudbenchTaskConfigResponseBodyData
from ._describe_error_log_records_request import DescribeErrorLogRecordsRequestFilters
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBodyDataLogs
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBodyData
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataBigKeysBigKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataBigKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHighTrafficKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHotKeysHotKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHotKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataLargeKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyData
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBodyDataHotKey
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBodyData
from ._describe_query_explain_response_body import DescribeQueryExplainResponseBodyData
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyData
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBodyData
from ._describe_slow_log_histogram_async_request import DescribeSlowLogHistogramAsyncRequestFilters
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataDataItem
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataData
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyData
from ._describe_slow_log_records_request import DescribeSlowLogRecordsRequestFilters
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyDataLogsSqlTag
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyDataLogs
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyData
from ._describe_slow_log_statistic_request import DescribeSlowLogStatisticRequestFilters
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsTrend
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogs
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataData
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyData
from ._describe_sql_log_config_response_body import DescribeSqlLogConfigResponseBodyData
from ._describe_sql_log_records_request import DescribeSqlLogRecordsRequestFilters
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyDataItemsSQLLogRecord
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyDataItems
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyData
from ._describe_sql_log_statistic_response_body import DescribeSqlLogStatisticResponseBodyData
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyDataFilters
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyDataQueries
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyData
from ._describe_sql_log_tasks_request import DescribeSqlLogTasksRequestFilters
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyDataListFilters
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyDataList
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyData
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBodyDataBigKey
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBodyData
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBodyDataHotKey
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBodyData
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyData
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyDataConfigFailInstanceList
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyDataConfigSuccessInstanceList
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyData
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBodyDataResult
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBodyData
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBodyDataResult
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBodyData
from ._get_async_error_request_stat_result_response_body import GetAsyncErrorRequestStatResultResponseBodyData
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBodyData
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyData
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyData
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBodyDataList
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBodyData
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBodyDataList
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBodyData
from ._get_dbinstance_connectivity_diagnosis_response_body import GetDBInstanceConnectivityDiagnosisResponseBodyData
from ._get_das_agent_sseresponse_body import GetDasAgentSSEResponseBodyMetadata
from ._get_das_pro_service_usage_response_body import GetDasProServiceUsageResponseBodyData
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBodyDataList
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBodyData
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyDataListBlockProcessList
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyDataList
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyData
from ._get_deadlock_histogram_response_body import GetDeadlockHistogramResponseBodyData
from ._get_endpoint_switch_task_response_body import GetEndpointSwitchTaskResponseBodyData
from ._get_error_request_sample_response_body import GetErrorRequestSampleResponseBodyData
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyDataContactGroups
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyDataContacts
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyData
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBodyDataList
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBodyData
from ._get_full_request_sample_by_instance_id_response_body import GetFullRequestSampleByInstanceIdResponseBodyData
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyDataResultList
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyDataResult
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyData
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyDataSubResults
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyData
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResults
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyData
from ._get_instance_group_inspect_report_detail_response_body import GetInstanceGroupInspectReportDetailResponseBodyData
from ._get_instance_group_inspect_report_list_response_body import GetInstanceGroupInspectReportListResponseBodyData
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataListAutoFunction
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataListInstance
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataList
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyData
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBodyDataList
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBodyData
from ._get_instance_sql_optimize_statistic_response_body import GetInstanceSqlOptimizeStatisticResponseBodyData
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBodyDataResult
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBodyData
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyDataSessionList
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyDataSessionStat
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyData
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionData
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyData
from ._get_pfs_sql_sample_response_body import GetPfsSqlSampleResponseBodyData
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBodyDataList
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBodyData
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyDataListRuleList
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyDataList
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyData
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBodyDataList
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBodyData
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBodyDataList
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBodyData
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBodyDataList
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBodyData
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBodyDataList
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBodyData
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBodyDataList
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBodyData
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBodyDataList
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBodyData
from ._get_query_optimize_tag_response_body import GetQueryOptimizeTagResponseBodyData
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyDataSessions
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyDataSourceStats
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyData
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBodyDataList
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBodyData
from ._get_request_diagnosis_result_response_body import GetRequestDiagnosisResultResponseBodyData
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyDataList
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyData
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyDataListRules
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyDataList
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyData
from ._get_sql_optimize_advice_response_body import GetSqlOptimizeAdviceResponseBodyData
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyData
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBodyFunctionCall
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBodyUiFunctionCall
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestBandwidth
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestResource
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestShard
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestSpec
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestStorage
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBodyData
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBodyData
from ._modify_sql_log_config_request import ModifySqlLogConfigRequestFilters
from ._modify_sql_log_config_response_body import ModifySqlLogConfigResponseBodyData
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBodyDataPreCheckItem
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBodyData
from ._set_event_subscription_response_body import SetEventSubscriptionResponseBodyData
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponse
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyData
from ._update_auto_sql_optimize_status_response_body import UpdateAutoSqlOptimizeStatusResponseBodyData
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponse
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyData

__all__ = [
    DataResultValue,
    DataSessionStatClientStatsValue,
    DataSessionStatDbStatsValue,
    DataValue,
    AddHDMInstanceRequest,
    AddHDMInstanceResponseBody,
    AddHDMInstanceResponse,
    CreateCacheAnalysisJobRequest,
    CreateCacheAnalysisJobResponseBody,
    CreateCacheAnalysisJobResponse,
    CreateCloudBenchTasksRequest,
    CreateCloudBenchTasksResponseBody,
    CreateCloudBenchTasksResponse,
    CreateDiagnosticReportRequest,
    CreateDiagnosticReportResponseBody,
    CreateDiagnosticReportResponse,
    CreateKillInstanceSessionTaskRequest,
    CreateKillInstanceSessionTaskResponseBody,
    CreateKillInstanceSessionTaskResponse,
    CreateKillInstanceSessionTaskWithMaintainUserRequest,
    CreateKillInstanceSessionTaskWithMaintainUserResponseBody,
    CreateKillInstanceSessionTaskWithMaintainUserResponse,
    CreateLatestDeadLockAnalysisRequest,
    CreateLatestDeadLockAnalysisResponseBody,
    CreateLatestDeadLockAnalysisResponse,
    CreateQueryOptimizeTagRequest,
    CreateQueryOptimizeTagResponseBody,
    CreateQueryOptimizeTagResponse,
    CreateRequestDiagnosisRequest,
    CreateRequestDiagnosisResponseBody,
    CreateRequestDiagnosisResponse,
    CreateSecurityIPGroupRequest,
    CreateSecurityIPGroupResponseBody,
    CreateSecurityIPGroupResponse,
    CreateSqlLogTaskRequest,
    CreateSqlLogTaskResponseBody,
    CreateSqlLogTaskResponse,
    CreateStorageAnalysisTaskRequest,
    CreateStorageAnalysisTaskResponseBody,
    CreateStorageAnalysisTaskResponse,
    DeleteCloudBenchTaskRequest,
    DeleteCloudBenchTaskResponseBody,
    DeleteCloudBenchTaskResponse,
    DeleteSecurityIPGroupRequest,
    DeleteSecurityIPGroupResponseBody,
    DeleteSecurityIPGroupResponse,
    DeleteStopGatewayRequest,
    DeleteStopGatewayResponseBody,
    DeleteStopGatewayResponse,
    DescribeAutoScalingConfigRequest,
    DescribeAutoScalingConfigResponseBody,
    DescribeAutoScalingConfigResponse,
    DescribeAutoScalingHistoryRequest,
    DescribeAutoScalingHistoryResponseBody,
    DescribeAutoScalingHistoryResponse,
    DescribeCacheAnalysisJobRequest,
    DescribeCacheAnalysisJobResponseBody,
    DescribeCacheAnalysisJobResponse,
    DescribeCacheAnalysisJobsRequest,
    DescribeCacheAnalysisJobsResponseBody,
    DescribeCacheAnalysisJobsResponse,
    DescribeCloudBenchTasksRequest,
    DescribeCloudBenchTasksResponseBody,
    DescribeCloudBenchTasksResponse,
    DescribeCloudbenchTaskRequest,
    DescribeCloudbenchTaskResponseBody,
    DescribeCloudbenchTaskResponse,
    DescribeCloudbenchTaskConfigRequest,
    DescribeCloudbenchTaskConfigResponseBody,
    DescribeCloudbenchTaskConfigResponse,
    DescribeDiagnosticReportListRequest,
    DescribeDiagnosticReportListResponseBody,
    DescribeDiagnosticReportListResponse,
    DescribeErrorLogRecordsRequest,
    DescribeErrorLogRecordsResponseBody,
    DescribeErrorLogRecordsResponse,
    DescribeHotBigKeysRequest,
    DescribeHotBigKeysResponseBody,
    DescribeHotBigKeysResponse,
    DescribeHotKeysRequest,
    DescribeHotKeysResponseBody,
    DescribeHotKeysResponse,
    DescribeInstanceDasProRequest,
    DescribeInstanceDasProResponseBody,
    DescribeInstanceDasProResponse,
    DescribeQueryExplainRequest,
    DescribeQueryExplainResponseBody,
    DescribeQueryExplainResponse,
    DescribeSecurityIPGroupRequest,
    DescribeSecurityIPGroupResponseBody,
    DescribeSecurityIPGroupResponse,
    DescribeSecurityIPGroupRelationRequest,
    DescribeSecurityIPGroupRelationResponseBody,
    DescribeSecurityIPGroupRelationResponse,
    DescribeSlowLogHistogramAsyncRequest,
    DescribeSlowLogHistogramAsyncResponseBody,
    DescribeSlowLogHistogramAsyncResponse,
    DescribeSlowLogRecordsRequest,
    DescribeSlowLogRecordsResponseBody,
    DescribeSlowLogRecordsResponse,
    DescribeSlowLogStatisticRequest,
    DescribeSlowLogStatisticResponseBody,
    DescribeSlowLogStatisticResponse,
    DescribeSqlLogConfigRequest,
    DescribeSqlLogConfigResponseBody,
    DescribeSqlLogConfigResponse,
    DescribeSqlLogRecordsRequest,
    DescribeSqlLogRecordsResponseBody,
    DescribeSqlLogRecordsResponse,
    DescribeSqlLogStatisticRequest,
    DescribeSqlLogStatisticResponseBody,
    DescribeSqlLogStatisticResponse,
    DescribeSqlLogTaskRequest,
    DescribeSqlLogTaskResponseBody,
    DescribeSqlLogTaskResponse,
    DescribeSqlLogTasksRequest,
    DescribeSqlLogTasksResponseBody,
    DescribeSqlLogTasksResponse,
    DescribeTopBigKeysRequest,
    DescribeTopBigKeysResponseBody,
    DescribeTopBigKeysResponse,
    DescribeTopHotKeysRequest,
    DescribeTopHotKeysResponseBody,
    DescribeTopHotKeysResponse,
    DisableAllSqlConcurrencyControlRulesRequest,
    DisableAllSqlConcurrencyControlRulesResponseBody,
    DisableAllSqlConcurrencyControlRulesResponse,
    DisableAutoResourceOptimizeRulesRequest,
    DisableAutoResourceOptimizeRulesResponseBody,
    DisableAutoResourceOptimizeRulesResponse,
    DisableAutoThrottleRulesRequest,
    DisableAutoThrottleRulesResponseBody,
    DisableAutoThrottleRulesResponse,
    DisableDasProRequest,
    DisableDasProResponseBody,
    DisableDasProResponse,
    DisableInstanceDasConfigRequest,
    DisableInstanceDasConfigResponseBody,
    DisableInstanceDasConfigResponse,
    DisableSqlConcurrencyControlRequest,
    DisableSqlConcurrencyControlResponseBody,
    DisableSqlConcurrencyControlResponse,
    EnableDasProRequest,
    EnableDasProResponseBody,
    EnableDasProResponse,
    EnableSqlConcurrencyControlRequest,
    EnableSqlConcurrencyControlResponseBody,
    EnableSqlConcurrencyControlResponse,
    GetAsyncErrorRequestListByCodeRequest,
    GetAsyncErrorRequestListByCodeResponseBody,
    GetAsyncErrorRequestListByCodeResponse,
    GetAsyncErrorRequestStatByCodeRequest,
    GetAsyncErrorRequestStatByCodeResponseBody,
    GetAsyncErrorRequestStatByCodeResponse,
    GetAsyncErrorRequestStatResultRequest,
    GetAsyncErrorRequestStatResultResponseBody,
    GetAsyncErrorRequestStatResultResponse,
    GetAutoIncrementUsageStatisticRequest,
    GetAutoIncrementUsageStatisticResponseBody,
    GetAutoIncrementUsageStatisticResponse,
    GetAutoResourceOptimizeRulesRequest,
    GetAutoResourceOptimizeRulesResponseBody,
    GetAutoResourceOptimizeRulesResponse,
    GetAutoThrottleRulesRequest,
    GetAutoThrottleRulesResponseBody,
    GetAutoThrottleRulesResponse,
    GetAutonomousNotifyEventContentRequest,
    GetAutonomousNotifyEventContentResponseBody,
    GetAutonomousNotifyEventContentResponse,
    GetAutonomousNotifyEventsInRangeRequest,
    GetAutonomousNotifyEventsInRangeResponseBody,
    GetAutonomousNotifyEventsInRangeResponse,
    GetBlockingDetailListRequest,
    GetBlockingDetailListResponseBody,
    GetBlockingDetailListResponse,
    GetDBInstanceConnectivityDiagnosisRequest,
    GetDBInstanceConnectivityDiagnosisResponseBody,
    GetDBInstanceConnectivityDiagnosisResponse,
    GetDasAgentSSERequest,
    GetDasAgentSSEResponseBody,
    GetDasAgentSSEResponse,
    GetDasProServiceUsageRequest,
    GetDasProServiceUsageResponseBody,
    GetDasProServiceUsageResponse,
    GetDasSQLLogHotDataRequest,
    GetDasSQLLogHotDataResponseBody,
    GetDasSQLLogHotDataResponse,
    GetDeadLockDetailRequest,
    GetDeadLockDetailResponseBody,
    GetDeadLockDetailResponse,
    GetDeadLockDetailListRequest,
    GetDeadLockDetailListResponseBody,
    GetDeadLockDetailListResponse,
    GetDeadLockHistoryRequest,
    GetDeadLockHistoryResponseBody,
    GetDeadLockHistoryResponse,
    GetDeadlockHistogramRequest,
    GetDeadlockHistogramResponseBody,
    GetDeadlockHistogramResponse,
    GetEndpointSwitchTaskRequest,
    GetEndpointSwitchTaskResponseBody,
    GetEndpointSwitchTaskResponse,
    GetErrorRequestSampleRequest,
    GetErrorRequestSampleResponseBody,
    GetErrorRequestSampleResponse,
    GetEventSubscriptionRequest,
    GetEventSubscriptionResponseBody,
    GetEventSubscriptionResponse,
    GetFullRequestOriginStatByInstanceIdRequest,
    GetFullRequestOriginStatByInstanceIdResponseBody,
    GetFullRequestOriginStatByInstanceIdResponse,
    GetFullRequestSampleByInstanceIdRequest,
    GetFullRequestSampleByInstanceIdResponseBody,
    GetFullRequestSampleByInstanceIdResponse,
    GetFullRequestStatResultByInstanceIdRequest,
    GetFullRequestStatResultByInstanceIdResponseBody,
    GetFullRequestStatResultByInstanceIdResponse,
    GetHDMAliyunResourceSyncResultRequest,
    GetHDMAliyunResourceSyncResultResponseBody,
    GetHDMAliyunResourceSyncResultResponse,
    GetHDMLastAliyunResourceSyncResultRequest,
    GetHDMLastAliyunResourceSyncResultResponseBody,
    GetHDMLastAliyunResourceSyncResultResponse,
    GetInstanceGroupInspectReportDetailRequest,
    GetInstanceGroupInspectReportDetailResponseBody,
    GetInstanceGroupInspectReportDetailResponse,
    GetInstanceGroupInspectReportListRequest,
    GetInstanceGroupInspectReportListResponseBody,
    GetInstanceGroupInspectReportListResponse,
    GetInstanceInspectionsRequest,
    GetInstanceInspectionsResponseBody,
    GetInstanceInspectionsResponse,
    GetInstanceMissingIndexListRequest,
    GetInstanceMissingIndexListResponseBody,
    GetInstanceMissingIndexListResponse,
    GetInstanceSqlOptimizeStatisticRequest,
    GetInstanceSqlOptimizeStatisticResponseBody,
    GetInstanceSqlOptimizeStatisticResponse,
    GetKillInstanceSessionTaskResultRequest,
    GetKillInstanceSessionTaskResultResponseBody,
    GetKillInstanceSessionTaskResultResponse,
    GetMongoDBCurrentOpRequest,
    GetMongoDBCurrentOpResponseBody,
    GetMongoDBCurrentOpResponse,
    GetMySQLAllSessionAsyncRequest,
    GetMySQLAllSessionAsyncResponseBody,
    GetMySQLAllSessionAsyncResponse,
    GetPartitionsHeatmapRequest,
    GetPartitionsHeatmapResponseBody,
    GetPartitionsHeatmapResponse,
    GetPfsMetricTrendsRequest,
    GetPfsMetricTrendsResponseBody,
    GetPfsMetricTrendsResponse,
    GetPfsSqlSampleRequest,
    GetPfsSqlSampleResponseBody,
    GetPfsSqlSampleResponse,
    GetPfsSqlSummariesRequest,
    GetPfsSqlSummariesResponseBody,
    GetPfsSqlSummariesResponse,
    GetQueryOptimizeDataStatsRequest,
    GetQueryOptimizeDataStatsResponseBody,
    GetQueryOptimizeDataStatsResponse,
    GetQueryOptimizeDataTopRequest,
    GetQueryOptimizeDataTopResponseBody,
    GetQueryOptimizeDataTopResponse,
    GetQueryOptimizeDataTrendRequest,
    GetQueryOptimizeDataTrendResponseBody,
    GetQueryOptimizeDataTrendResponse,
    GetQueryOptimizeExecErrorSampleRequest,
    GetQueryOptimizeExecErrorSampleResponseBody,
    GetQueryOptimizeExecErrorSampleResponse,
    GetQueryOptimizeExecErrorStatsRequest,
    GetQueryOptimizeExecErrorStatsResponseBody,
    GetQueryOptimizeExecErrorStatsResponse,
    GetQueryOptimizeRuleListRequest,
    GetQueryOptimizeRuleListResponseBody,
    GetQueryOptimizeRuleListResponse,
    GetQueryOptimizeShareUrlRequest,
    GetQueryOptimizeShareUrlResponseBody,
    GetQueryOptimizeShareUrlResponse,
    GetQueryOptimizeSolutionRequest,
    GetQueryOptimizeSolutionResponseBody,
    GetQueryOptimizeSolutionResponse,
    GetQueryOptimizeTagRequest,
    GetQueryOptimizeTagResponseBody,
    GetQueryOptimizeTagResponse,
    GetRedisAllSessionRequest,
    GetRedisAllSessionResponseBody,
    GetRedisAllSessionResponse,
    GetRequestDiagnosisPageRequest,
    GetRequestDiagnosisPageResponseBody,
    GetRequestDiagnosisPageResponse,
    GetRequestDiagnosisResultRequest,
    GetRequestDiagnosisResultResponseBody,
    GetRequestDiagnosisResultResponse,
    GetRunningSqlConcurrencyControlRulesRequest,
    GetRunningSqlConcurrencyControlRulesResponseBody,
    GetRunningSqlConcurrencyControlRulesResponse,
    GetSqlConcurrencyControlKeywordsFromSqlTextRequest,
    GetSqlConcurrencyControlKeywordsFromSqlTextResponseBody,
    GetSqlConcurrencyControlKeywordsFromSqlTextResponse,
    GetSqlConcurrencyControlRulesHistoryRequest,
    GetSqlConcurrencyControlRulesHistoryResponseBody,
    GetSqlConcurrencyControlRulesHistoryResponse,
    GetSqlOptimizeAdviceRequest,
    GetSqlOptimizeAdviceResponseBody,
    GetSqlOptimizeAdviceResponse,
    GetStorageAnalysisResultRequest,
    GetStorageAnalysisResultResponseBody,
    GetStorageAnalysisResultResponse,
    GetYaoChiAgentRequest,
    GetYaoChiAgentResponseBody,
    GetYaoChiAgentResponse,
    KillInstanceAllSessionRequest,
    KillInstanceAllSessionResponseBody,
    KillInstanceAllSessionResponse,
    ModifyAutoScalingConfigRequest,
    ModifyAutoScalingConfigResponseBody,
    ModifyAutoScalingConfigResponse,
    ModifySecurityIPGroupRequest,
    ModifySecurityIPGroupResponseBody,
    ModifySecurityIPGroupResponse,
    ModifySecurityIPGroupRelationRequest,
    ModifySecurityIPGroupRelationResponseBody,
    ModifySecurityIPGroupRelationResponse,
    ModifySqlLogConfigRequest,
    ModifySqlLogConfigResponseBody,
    ModifySqlLogConfigResponse,
    RunCloudBenchTaskRequest,
    RunCloudBenchTaskResponseBody,
    RunCloudBenchTaskResponse,
    SetEventSubscriptionRequest,
    SetEventSubscriptionResponseBody,
    SetEventSubscriptionResponse,
    UpdateAutoResourceOptimizeRulesAsyncRequest,
    UpdateAutoResourceOptimizeRulesAsyncResponseBody,
    UpdateAutoResourceOptimizeRulesAsyncResponse,
    UpdateAutoSqlOptimizeStatusRequest,
    UpdateAutoSqlOptimizeStatusResponseBody,
    UpdateAutoSqlOptimizeStatusResponse,
    UpdateAutoThrottleRulesAsyncRequest,
    UpdateAutoThrottleRulesAsyncResponseBody,
    UpdateAutoThrottleRulesAsyncResponse,
    AddHDMInstanceResponseBodyData,
    CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo,
    CreateCacheAnalysisJobResponseBodyDataBigKeys,
    CreateCacheAnalysisJobResponseBodyData,
    CreateCloudBenchTasksResponseBodyData,
    CreateSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    CreateSecurityIPGroupResponseBodyData,
    CreateSqlLogTaskRequestFilters,
    CreateSqlLogTaskResponseBodyData,
    CreateStorageAnalysisTaskResponseBodyData,
    DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    DeleteSecurityIPGroupResponseBodyData,
    DescribeAutoScalingConfigResponseBodyDataBandwidth,
    DescribeAutoScalingConfigResponseBodyDataResource,
    DescribeAutoScalingConfigResponseBodyDataShard,
    DescribeAutoScalingConfigResponseBodyDataSpec,
    DescribeAutoScalingConfigResponseBodyDataStorage,
    DescribeAutoScalingConfigResponseBodyData,
    DescribeAutoScalingHistoryResponseBodyDataSpecHistory,
    DescribeAutoScalingHistoryResponseBodyData,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataBigKeys,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum,
    DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel,
    DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount,
    DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix,
    DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum,
    DescribeCacheAnalysisJobResponseBodyData,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeysKeyInfo,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeys,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJob,
    DescribeCacheAnalysisJobsResponseBodyDataList,
    DescribeCacheAnalysisJobsResponseBodyData,
    DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks,
    DescribeCloudBenchTasksResponseBodyDataList,
    DescribeCloudBenchTasksResponseBodyData,
    DescribeCloudbenchTaskResponseBodyData,
    DescribeCloudbenchTaskConfigResponseBodyData,
    DescribeErrorLogRecordsRequestFilters,
    DescribeErrorLogRecordsResponseBodyDataLogs,
    DescribeErrorLogRecordsResponseBodyData,
    DescribeHotBigKeysResponseBodyDataBigKeysBigKey,
    DescribeHotBigKeysResponseBodyDataBigKeys,
    DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey,
    DescribeHotBigKeysResponseBodyDataHighTrafficKeys,
    DescribeHotBigKeysResponseBodyDataHotKeysHotKey,
    DescribeHotBigKeysResponseBodyDataHotKeys,
    DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey,
    DescribeHotBigKeysResponseBodyDataLargeKeys,
    DescribeHotBigKeysResponseBodyData,
    DescribeHotKeysResponseBodyDataHotKey,
    DescribeHotKeysResponseBodyData,
    DescribeQueryExplainResponseBodyData,
    DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList,
    DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups,
    DescribeSecurityIPGroupResponseBodyData,
    DescribeSecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel,
    DescribeSecurityIPGroupRelationResponseBodyData,
    DescribeSlowLogHistogramAsyncRequestFilters,
    DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems,
    DescribeSlowLogHistogramAsyncResponseBodyDataDataItem,
    DescribeSlowLogHistogramAsyncResponseBodyDataData,
    DescribeSlowLogHistogramAsyncResponseBodyData,
    DescribeSlowLogRecordsRequestFilters,
    DescribeSlowLogRecordsResponseBodyDataLogsSqlTag,
    DescribeSlowLogRecordsResponseBodyDataLogs,
    DescribeSlowLogRecordsResponseBodyData,
    DescribeSlowLogStatisticRequestFilters,
    DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem,
    DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram,
    DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag,
    DescribeSlowLogStatisticResponseBodyDataDataLogsTrend,
    DescribeSlowLogStatisticResponseBodyDataDataLogs,
    DescribeSlowLogStatisticResponseBodyDataData,
    DescribeSlowLogStatisticResponseBodyData,
    DescribeSqlLogConfigResponseBodyData,
    DescribeSqlLogRecordsRequestFilters,
    DescribeSqlLogRecordsResponseBodyDataItemsSQLLogRecord,
    DescribeSqlLogRecordsResponseBodyDataItems,
    DescribeSqlLogRecordsResponseBodyData,
    DescribeSqlLogStatisticResponseBodyData,
    DescribeSqlLogTaskResponseBodyDataFilters,
    DescribeSqlLogTaskResponseBodyDataQueries,
    DescribeSqlLogTaskResponseBodyData,
    DescribeSqlLogTasksRequestFilters,
    DescribeSqlLogTasksResponseBodyDataListFilters,
    DescribeSqlLogTasksResponseBodyDataList,
    DescribeSqlLogTasksResponseBodyData,
    DescribeTopBigKeysResponseBodyDataBigKey,
    DescribeTopBigKeysResponseBodyData,
    DescribeTopHotKeysResponseBodyDataHotKey,
    DescribeTopHotKeysResponseBodyData,
    DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList,
    DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList,
    DisableAutoResourceOptimizeRulesResponseBodyData,
    DisableAutoThrottleRulesResponseBodyDataConfigFailInstanceList,
    DisableAutoThrottleRulesResponseBodyDataConfigSuccessInstanceList,
    DisableAutoThrottleRulesResponseBodyData,
    GetAsyncErrorRequestListByCodeResponseBodyDataResult,
    GetAsyncErrorRequestListByCodeResponseBodyData,
    GetAsyncErrorRequestStatByCodeResponseBodyDataResult,
    GetAsyncErrorRequestStatByCodeResponseBodyData,
    GetAsyncErrorRequestStatResultResponseBodyData,
    GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList,
    GetAutoIncrementUsageStatisticResponseBodyData,
    GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList,
    GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList,
    GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList,
    GetAutoResourceOptimizeRulesResponseBodyData,
    GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList,
    GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList,
    GetAutoThrottleRulesResponseBodyData,
    GetAutonomousNotifyEventsInRangeResponseBodyDataList,
    GetAutonomousNotifyEventsInRangeResponseBodyData,
    GetBlockingDetailListResponseBodyDataList,
    GetBlockingDetailListResponseBodyData,
    GetDBInstanceConnectivityDiagnosisResponseBodyData,
    GetDasAgentSSEResponseBodyMetadata,
    GetDasProServiceUsageResponseBodyData,
    GetDasSQLLogHotDataResponseBodyDataList,
    GetDasSQLLogHotDataResponseBodyData,
    GetDeadLockDetailListResponseBodyDataListBlockProcessList,
    GetDeadLockDetailListResponseBodyDataList,
    GetDeadLockDetailListResponseBodyData,
    GetDeadlockHistogramResponseBodyData,
    GetEndpointSwitchTaskResponseBodyData,
    GetErrorRequestSampleResponseBodyData,
    GetEventSubscriptionResponseBodyDataContactGroups,
    GetEventSubscriptionResponseBodyDataContacts,
    GetEventSubscriptionResponseBodyData,
    GetFullRequestOriginStatByInstanceIdResponseBodyDataList,
    GetFullRequestOriginStatByInstanceIdResponseBodyData,
    GetFullRequestSampleByInstanceIdResponseBodyData,
    GetFullRequestStatResultByInstanceIdResponseBodyDataResultList,
    GetFullRequestStatResultByInstanceIdResponseBodyDataResult,
    GetFullRequestStatResultByInstanceIdResponseBodyData,
    GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult,
    GetHDMAliyunResourceSyncResultResponseBodyDataSubResults,
    GetHDMAliyunResourceSyncResultResponseBodyData,
    GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult,
    GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResults,
    GetHDMLastAliyunResourceSyncResultResponseBodyData,
    GetInstanceGroupInspectReportDetailResponseBodyData,
    GetInstanceGroupInspectReportListResponseBodyData,
    GetInstanceInspectionsResponseBodyDataListAutoFunction,
    GetInstanceInspectionsResponseBodyDataListInstance,
    GetInstanceInspectionsResponseBodyDataList,
    GetInstanceInspectionsResponseBodyData,
    GetInstanceMissingIndexListResponseBodyDataList,
    GetInstanceMissingIndexListResponseBodyData,
    GetInstanceSqlOptimizeStatisticResponseBodyData,
    GetKillInstanceSessionTaskResultResponseBodyDataResult,
    GetKillInstanceSessionTaskResultResponseBodyData,
    GetMongoDBCurrentOpResponseBodyDataSessionList,
    GetMongoDBCurrentOpResponseBodyDataSessionStat,
    GetMongoDBCurrentOpResponseBodyData,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionData,
    GetMySQLAllSessionAsyncResponseBodyData,
    GetPfsSqlSampleResponseBodyData,
    GetPfsSqlSummariesResponseBodyDataList,
    GetPfsSqlSummariesResponseBodyData,
    GetQueryOptimizeDataStatsResponseBodyDataListRuleList,
    GetQueryOptimizeDataStatsResponseBodyDataList,
    GetQueryOptimizeDataStatsResponseBodyData,
    GetQueryOptimizeDataTopResponseBodyDataList,
    GetQueryOptimizeDataTopResponseBodyData,
    GetQueryOptimizeDataTrendResponseBodyDataList,
    GetQueryOptimizeDataTrendResponseBodyData,
    GetQueryOptimizeExecErrorSampleResponseBodyDataList,
    GetQueryOptimizeExecErrorSampleResponseBodyData,
    GetQueryOptimizeExecErrorStatsResponseBodyDataList,
    GetQueryOptimizeExecErrorStatsResponseBodyData,
    GetQueryOptimizeRuleListResponseBodyDataList,
    GetQueryOptimizeRuleListResponseBodyData,
    GetQueryOptimizeSolutionResponseBodyDataList,
    GetQueryOptimizeSolutionResponseBodyData,
    GetQueryOptimizeTagResponseBodyData,
    GetRedisAllSessionResponseBodyDataSessions,
    GetRedisAllSessionResponseBodyDataSourceStats,
    GetRedisAllSessionResponseBodyData,
    GetRequestDiagnosisPageResponseBodyDataList,
    GetRequestDiagnosisPageResponseBodyData,
    GetRequestDiagnosisResultResponseBodyData,
    GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules,
    GetRunningSqlConcurrencyControlRulesResponseBodyDataList,
    GetRunningSqlConcurrencyControlRulesResponseBodyData,
    GetSqlConcurrencyControlRulesHistoryResponseBodyDataListRules,
    GetSqlConcurrencyControlRulesHistoryResponseBodyDataList,
    GetSqlConcurrencyControlRulesHistoryResponseBodyData,
    GetSqlOptimizeAdviceResponseBodyData,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult,
    GetStorageAnalysisResultResponseBodyData,
    GetYaoChiAgentResponseBodyFunctionCall,
    GetYaoChiAgentResponseBodyUiFunctionCall,
    ModifyAutoScalingConfigRequestBandwidth,
    ModifyAutoScalingConfigRequestResource,
    ModifyAutoScalingConfigRequestShard,
    ModifyAutoScalingConfigRequestSpec,
    ModifyAutoScalingConfigRequestStorage,
    ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    ModifySecurityIPGroupResponseBodyData,
    ModifySecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel,
    ModifySecurityIPGroupRelationResponseBodyData,
    ModifySqlLogConfigRequestFilters,
    ModifySqlLogConfigResponseBodyData,
    RunCloudBenchTaskResponseBodyDataPreCheckItem,
    RunCloudBenchTaskResponseBodyData,
    SetEventSubscriptionResponseBodyData,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponse,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyData,
    UpdateAutoSqlOptimizeStatusResponseBodyData,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponse,
    UpdateAutoThrottleRulesAsyncResponseBodyData
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class ModifySqlLogConfigResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.ModifySqlLogConfigResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The response code.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.ModifySqlLogConfigResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class ModifySqlLogConfigResponseBodyData(DaraModel):
    def __init__(
        self,
        cold_enable: bool = None,
        cold_retention: int = None,
        cold_start_time: int = None,
        collector_version: str = None,
        hot_enable: bool = None,
        hot_retention: int = None,
        hot_start_time: int = None,
        log_filter: str = None,
        request_enable: bool = None,
        request_start_time: int = None,
        request_stop_time: int = None,
        retention: int = None,
        sql_log_enable: bool = None,
        sql_log_source: str = None,
        sql_log_state: str = None,
        sql_log_visible_time: int = None,
        support_version: str = None,
        version: str = None,
    ):
        # Indicates whether the cold data storage is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.cold_enable = cold_enable
        # The number of days for which the SQL Explorer and Audit data is stored in cold storage. The value is calculated by using the following formula: Value of ColdRetention = Value of Retention - Value of HotRetention.``
        self.cold_retention = cold_retention
        # The time when the cold data storage was enabled. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.cold_start_time = cold_start_time
        # The collector version. Valid values:
        # 
        # *   **MYSQL_V0**
        # *   **MYSQL_V1**
        # *   **MYSQL_V2**
        # *   **MYSQL_V3**
        # *   **PG_V1**
        # *   **rdspg_v1**
        # *   **polarpg_v1**
        self.collector_version = collector_version
        # Indicates whether the hot data storage is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.hot_enable = hot_enable
        # The number of days for which the SQL Explorer and Audit data is stored in hot storage.
        self.hot_retention = hot_retention
        # The time when the hot data storage was enabled. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.hot_start_time = hot_start_time
        # A reserved parameter.
        self.log_filter = log_filter
        # Indicates whether the SQL Explorer feature is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.request_enable = request_enable
        # The time when the SQL Explorer feature was enabled. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.request_start_time = request_start_time
        # The time when DAS Enterprise Edition V1 expired. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.request_stop_time = request_stop_time
        # The total storage duration of the SQL Explorer and Audit data. Unit: day.
        self.retention = retention
        # Indicates whether DAS Enterprise Edition is enabled. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.sql_log_enable = sql_log_enable
        self.sql_log_source = sql_log_source
        # The state of data migration. Valid values:
        # 
        # *   **FINISH**: The historical data is migrated.
        # *   **RUNNING**: The historical data is being migrated.
        # *   **FAILURE**: The historical data fails to be migrated.
        self.sql_log_state = sql_log_state
        # The time when DAS Enterprise Edition was enabled. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.sql_log_visible_time = sql_log_visible_time
        # The latest version of DAS Enterprise Edition that supports the database instance. Valid values:
        # 
        # *   **SQL_LOG_V0**: DAS Enterprise Edition V0.
        # *   **SQL_LOG_V1**: DAS Enterprise Edition V1.
        # *   **SQL_LOG_V2**: DAS Enterprise Edition V2.
        # *   **SQL_LOG_V3**: DAS Enterprise Edition V3.
        # *   **SQL_LOG_NOT_ENABLE**: DAS Enterprise Edition is not enabled.
        # *   **SQL_LOG_NOT_SUPPORT**: DAS Enterprise Edition is not supported.
        self.support_version = support_version
        # The version of DAS Enterprise Edition that is enabled for the database instance. Valid values:
        # 
        # *   **SQL_LOG_V0**: DAS Enterprise Edition V0.
        # *   **SQL_LOG_V1**: DAS Enterprise Edition V1.
        # *   **SQL_LOG_V2**: DAS Enterprise Edition V2.
        # *   **SQL_LOG_V3**: DAS Enterprise Edition V3.
        # *   **SQL_LOG_NOT_ENABLE**: DAS Enterprise Edition is not enabled.
        # *   **SQL_LOG_NOT_SUPPORT**: DAS Enterprise Edition is not supported.
        self.version = version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cold_enable is not None:
            result['ColdEnable'] = self.cold_enable

        if self.cold_retention is not None:
            result['ColdRetention'] = self.cold_retention

        if self.cold_start_time is not None:
            result['ColdStartTime'] = self.cold_start_time

        if self.collector_version is not None:
            result['CollectorVersion'] = self.collector_version

        if self.hot_enable is not None:
            result['HotEnable'] = self.hot_enable

        if self.hot_retention is not None:
            result['HotRetention'] = self.hot_retention

        if self.hot_start_time is not None:
            result['HotStartTime'] = self.hot_start_time

        if self.log_filter is not None:
            result['LogFilter'] = self.log_filter

        if self.request_enable is not None:
            result['RequestEnable'] = self.request_enable

        if self.request_start_time is not None:
            result['RequestStartTime'] = self.request_start_time

        if self.request_stop_time is not None:
            result['RequestStopTime'] = self.request_stop_time

        if self.retention is not None:
            result['Retention'] = self.retention

        if self.sql_log_enable is not None:
            result['SqlLogEnable'] = self.sql_log_enable

        if self.sql_log_source is not None:
            result['SqlLogSource'] = self.sql_log_source

        if self.sql_log_state is not None:
            result['SqlLogState'] = self.sql_log_state

        if self.sql_log_visible_time is not None:
            result['SqlLogVisibleTime'] = self.sql_log_visible_time

        if self.support_version is not None:
            result['SupportVersion'] = self.support_version

        if self.version is not None:
            result['Version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ColdEnable') is not None:
            self.cold_enable = m.get('ColdEnable')

        if m.get('ColdRetention') is not None:
            self.cold_retention = m.get('ColdRetention')

        if m.get('ColdStartTime') is not None:
            self.cold_start_time = m.get('ColdStartTime')

        if m.get('CollectorVersion') is not None:
            self.collector_version = m.get('CollectorVersion')

        if m.get('HotEnable') is not None:
            self.hot_enable = m.get('HotEnable')

        if m.get('HotRetention') is not None:
            self.hot_retention = m.get('HotRetention')

        if m.get('HotStartTime') is not None:
            self.hot_start_time = m.get('HotStartTime')

        if m.get('LogFilter') is not None:
            self.log_filter = m.get('LogFilter')

        if m.get('RequestEnable') is not None:
            self.request_enable = m.get('RequestEnable')

        if m.get('RequestStartTime') is not None:
            self.request_start_time = m.get('RequestStartTime')

        if m.get('RequestStopTime') is not None:
            self.request_stop_time = m.get('RequestStopTime')

        if m.get('Retention') is not None:
            self.retention = m.get('Retention')

        if m.get('SqlLogEnable') is not None:
            self.sql_log_enable = m.get('SqlLogEnable')

        if m.get('SqlLogSource') is not None:
            self.sql_log_source = m.get('SqlLogSource')

        if m.get('SqlLogState') is not None:
            self.sql_log_state = m.get('SqlLogState')

        if m.get('SqlLogVisibleTime') is not None:
            self.sql_log_visible_time = m.get('SqlLogVisibleTime')

        if m.get('SupportVersion') is not None:
            self.support_version = m.get('SupportVersion')

        if m.get('Version') is not None:
            self.version = m.get('Version')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetEventSubscriptionResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetEventSubscriptionResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetEventSubscriptionResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetEventSubscriptionResponseBodyData(DaraModel):
    def __init__(
        self,
        active: int = None,
        channel_type: str = None,
        contact_group_name: str = None,
        contact_groups: List[main_models.GetEventSubscriptionResponseBodyDataContactGroups] = None,
        contact_name: str = None,
        contacts: List[main_models.GetEventSubscriptionResponseBodyDataContacts] = None,
        event_context: str = None,
        event_send_group: List[str] = None,
        gmt_create: int = None,
        gmt_modified: int = None,
        id: int = None,
        instance_id: str = None,
        lang: str = None,
        level: str = None,
        min_interval: str = None,
        user_id: str = None,
    ):
        # Indicates whether the event subscription feature is enabled. Valid values:
        # 
        # *   **0**: The event subscription feature is disabled.
        # *   **1**: The event subscription feature is enabled.
        self.active = active
        # The notification method. Valid values:
        # 
        # *   **hdm_alarm_sms**: text message.
        # *   **dingtalk**: DingTalk chatbot.
        # *   **hdm_alarm_sms_and_email**: text message and email.
        # *   **hdm_alarm_sms,dingtalk**: text message and DingTalk chatbot.
        self.channel_type = channel_type
        # The name of the contact group that receives alert notifications. Multiple names are separated by commas (,).
        self.contact_group_name = contact_group_name
        # The alert contact groups.
        self.contact_groups = contact_groups
        # The name of the subscriber who receives alert notifications. Multiple names are separated by commas (,).
        self.contact_name = contact_name
        # The user ID.
        self.contacts = contacts
        # The supported event scenarios. Only **AllContext** may be returned, which indicates that all scenarios are supported.
        self.event_context = event_context
        # The supported event scenarios in which event subscription can be sent.
        self.event_send_group = event_send_group
        # The time when event subscription was enabled. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.gmt_create = gmt_create
        # The time when the event subscription settings were most recently modified. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.gmt_modified = gmt_modified
        # The primary key ID of the database.
        self.id = id
        # The instance ID.
        self.instance_id = instance_id
        # The language of event notifications. Only **zh-CN** may be returned, which indicates that event notifications are sent in Chinese.
        self.lang = lang
        # The risk level of the events that trigger notifications. Valid values:
        # 
        # *   **Notice**
        # *   **Optimization**
        # *   **Warn**
        # *   **Critical**
        self.level = level
        # The minimum interval between event notifications. Unit: seconds.
        self.min_interval = min_interval
        # The user ID.
        self.user_id = user_id

    def validate(self):
        if self.contact_groups:
            for v1 in self.contact_groups:
                 if v1:
                    v1.validate()
        if self.contacts:
            for v1 in self.contacts:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active is not None:
            result['active'] = self.active

        if self.channel_type is not None:
            result['channelType'] = self.channel_type

        if self.contact_group_name is not None:
            result['contactGroupName'] = self.contact_group_name

        result['contactGroups'] = []
        if self.contact_groups is not None:
            for k1 in self.contact_groups:
                result['contactGroups'].append(k1.to_map() if k1 else None)

        if self.contact_name is not None:
            result['contactName'] = self.contact_name

        result['contacts'] = []
        if self.contacts is not None:
            for k1 in self.contacts:
                result['contacts'].append(k1.to_map() if k1 else None)

        if self.event_context is not None:
            result['eventContext'] = self.event_context

        if self.event_send_group is not None:
            result['eventSendGroup'] = self.event_send_group

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.id is not None:
            result['id'] = self.id

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.lang is not None:
            result['lang'] = self.lang

        if self.level is not None:
            result['level'] = self.level

        if self.min_interval is not None:
            result['minInterval'] = self.min_interval

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('active') is not None:
            self.active = m.get('active')

        if m.get('channelType') is not None:
            self.channel_type = m.get('channelType')

        if m.get('contactGroupName') is not None:
            self.contact_group_name = m.get('contactGroupName')

        self.contact_groups = []
        if m.get('contactGroups') is not None:
            for k1 in m.get('contactGroups'):
                temp_model = main_models.GetEventSubscriptionResponseBodyDataContactGroups()
                self.contact_groups.append(temp_model.from_map(k1))

        if m.get('contactName') is not None:
            self.contact_name = m.get('contactName')

        self.contacts = []
        if m.get('contacts') is not None:
            for k1 in m.get('contacts'):
                temp_model = main_models.GetEventSubscriptionResponseBodyDataContacts()
                self.contacts.append(temp_model.from_map(k1))

        if m.get('eventContext') is not None:
            self.event_context = m.get('eventContext')

        if m.get('eventSendGroup') is not None:
            self.event_send_group = m.get('eventSendGroup')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('lang') is not None:
            self.lang = m.get('lang')

        if m.get('level') is not None:
            self.level = m.get('level')

        if m.get('minInterval') is not None:
            self.min_interval = m.get('minInterval')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self

class GetEventSubscriptionResponseBodyDataContacts(DaraModel):
    def __init__(
        self,
        dingtalk_hook: str = None,
        email: str = None,
        groups: List[str] = None,
        is_cms_reduplicated: bool = None,
        name: str = None,
        phone: str = None,
        user_id: str = None,
    ):
        # The webhook URL of the DingTalk chatbot.
        self.dingtalk_hook = dingtalk_hook
        # The email address of the alert contact.
        self.email = email
        # The contact groups to which the alert contact belongs.
        self.groups = groups
        # Indicates whether the alert contact name is the same as the contact name on CloudMonitor.
        # 
        # * **true**
        # * **false**
        self.is_cms_reduplicated = is_cms_reduplicated
        # The name of the alert contact.
        self.name = name
        # The mobile number of the alert contact.
        self.phone = phone
        # The user ID.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.dingtalk_hook is not None:
            result['dingtalkHook'] = self.dingtalk_hook

        if self.email is not None:
            result['email'] = self.email

        if self.groups is not None:
            result['groups'] = self.groups

        if self.is_cms_reduplicated is not None:
            result['isCmsReduplicated'] = self.is_cms_reduplicated

        if self.name is not None:
            result['name'] = self.name

        if self.phone is not None:
            result['phone'] = self.phone

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('dingtalkHook') is not None:
            self.dingtalk_hook = m.get('dingtalkHook')

        if m.get('email') is not None:
            self.email = m.get('email')

        if m.get('groups') is not None:
            self.groups = m.get('groups')

        if m.get('isCmsReduplicated') is not None:
            self.is_cms_reduplicated = m.get('isCmsReduplicated')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('phone') is not None:
            self.phone = m.get('phone')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self

class GetEventSubscriptionResponseBodyDataContactGroups(DaraModel):
    def __init__(
        self,
        contacts: str = None,
        description: str = None,
        name: str = None,
        user_id: str = None,
    ):
        # The members of the alert contact group.
        self.contacts = contacts
        # The description of the alert contact group.
        self.description = description
        # The name of the alert contact group.
        self.name = name
        # The user ID.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.contacts is not None:
            result['contacts'] = self.contacts

        if self.description is not None:
            result['description'] = self.description

        if self.name is not None:
            result['name'] = self.name

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('contacts') is not None:
            self.contacts = m.get('contacts')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self

